# Tams-MathLib-OpenSources

Tams merupakan sebuah project library open sources python untuk operasi matematika yang sintaksnya
menggunakana bahasa indonesia.

## Kebutuhan dan Installasi

Buat kalian yang ingin install `Tams` dibutuhkan minimal versi python `3.10`.
Untuk installasi bisa dilakukan dengan cara dibawah ini:

```bash
pip install git+https://github.com/AryaWiratama26/Tams-MathLib-OpenSources
```

## Contoh 

```bash
import Tams.matematika as mtk

print(mtk.tambah(2,5))
print(mtk.kurang(3,4))
print(mtk.kali(2,4))
print(mtk.bagi(2,7))

```

```
tambah() untuk pertambahan
kurang() untuk perkurangam
kali() untuk perkalian
bagi() untuk pembagian
fibonacci() untuk menghitung deret fibonacci
rata() untuk mencari nilai rata-rata
faktorial() untuk mencari nilai faktorial
nilai_terkecil() untuk mencari nilai terkecil
nilai_terbesar() untuk mencari nilai terbesar

```